@@ -18,9 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt.h,v 1.2 2000/09/16 02:01:38 nmav Exp $ */
 
-#define MCRYPT_API_VERSION 20000320
+#define MCRYPT_API_VERSION 20010501
+#define LIBMCRYPT_VERSION "2.4.13"
 
 #ifdef __cplusplus
 extern "C" {
@@ -28,9 +28,9 @@ extern "C" {
 /* Definitions
  */
 #define MCRYPT_FAILED 0x0
-	struct CRYPT_STREAM;
-	typedef struct CRYPT_STREAM *MCRYPT;
 
+struct CRYPT_STREAM;
+typedef struct CRYPT_STREAM *MCRYPT;
 
 /* generic - high level functions. 
  */
@@ -44,13 +44,14 @@ extern "C" {
 
 	int mcrypt_generic_init(const MCRYPT td, void *key, int lenofkey,
 				void *IV);
+	int mcrypt_generic_deinit(const MCRYPT td);
 	int mcrypt_generic_end(const MCRYPT td);
 	int mdecrypt_generic(MCRYPT td, void *plaintext, int len);
 	int mcrypt_generic(MCRYPT td, void *plaintext, int len);
 
 /* extra functions */
 
-     int mcrypt_enc_set_state(MCRYPT td, void *iv, int size); /* only for block algorithms */
+	int mcrypt_enc_set_state(MCRYPT td, void *iv, int size); /* only for block algorithms */
 	int (mcrypt_enc_self_test) (MCRYPT);
 	int (mcrypt_enc_get_block_size) (MCRYPT);
 	int (mcrypt_enc_get_iv_size) (MCRYPT);
@@ -89,6 +90,7 @@ extern "C" {
 	 * to this function, it will print a human readable message
 	 */
 	void mcrypt_perror(int err);
+	char* mcrypt_strerror(int err);
 
 	/* Self test for the specified algorithm 
 	 */
@@ -116,6 +118,12 @@ extern "C" {
 	int mcrypt_module_mode_version(char *mode, char *a_directory);
 
 
+	/* for multithreaded applications: 
+	 */
+	int mcrypt_mutex_register ( void (*mutex_lock)(void) , 
+			void (*mutex_unlock)(void), 
+			void (*set_error)(const char*), 
+			const char* (*get_error)(void));
 
 	/* These definitions exist in order to ease the access to 
 	 * mcrypt_module_init().
