@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: mcrypt_extra.c,v 1.7 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: mcrypt_extra.c,v 1.11 2001/05/18 10:54:14 nmav Exp $ */
 
 #ifndef LIBDEFS_H
 #define LIBDEFS_H
@@ -27,9 +27,6 @@
 #include <xmemory.h>
 #include <mcrypt_internal.h>
 
-#if 0
-extern int preloaded_symbols;
-#endif
 
 int mcrypt_algorithm_module_ok(const char *file, const char *directory);
 int mcrypt_mode_module_ok(const char *file, const char *directory);
@@ -93,8 +90,10 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
 
 	pdir = opendir(directory);
 	if (pdir == NULL) {
+#ifdef DEBUG
 		fprintf(stderr, "Unable to open directory %s.\n",
 			directory);
+#endif
 		return NULL;
 	}
 
@@ -109,12 +108,15 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
 					    realloc(filename,
 						    (*size +
 						     1) * sizeof(char *));
-					if (filename==NULL) return NULL;
+					if (filename==NULL) {
+						free(dirname);
+						return NULL;
+					}
 					filename[*size] =
 					    calloc(1, tmpsize + 1);
 					if (filename[*size]==NULL) return NULL;
 					strcpy(filename[*size], dirname);
-
+					
 					ptr =
 					    strrchr(filename[*size], '.');
 					if (ptr != NULL)
@@ -122,6 +124,7 @@ WIN32DLL_DEFINE char **mcrypt_list_algorithms(char *libdir, int *size)
 					(*size)++;
 				}
 			}
+			free(dirname);
 		} else {
 			break;
 		}
@@ -151,8 +154,10 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(char *libdir, int *size)
 
 	pdir = opendir(directory);
 	if (pdir == NULL) {
+#ifdef DEBUG
 		fprintf(stderr, "Unable to open directory %s.\n",
 			directory);
+#endif
 		return NULL;
 	}
 
@@ -169,8 +174,10 @@ WIN32DLL_DEFINE char **mcrypt_list_modes(char *libdir, int *size)
 					    realloc(filename,
 						    (*size +
 						     1) * sizeof(char *));
-					if (filename==NULL) return NULL;
-					
+					if (filename==NULL) {
+						free(dirname);
+						return NULL;
+					}
 					filename[*size] =
 					    calloc(1, tmpsize + 1);
 					if (filename[*size]==NULL) return NULL;
@@ -208,7 +215,7 @@ WIN32DLL_DEFINE
     int mcrypt_algorithm_module_ok(const char *file, const char *directory)
 {
 	word32 ret;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_version) (void);
 
 	if (file == NULL && directory == NULL) {
@@ -225,9 +232,6 @@ WIN32DLL_DEFINE
 	_handle = mcrypt_dlopen(directory, NULL, file);
 
 	if (!_handle) {
-/*		fputs(lt_dlerror(), stderr);
- *		fputs("\n", stderr);
- */
 		lt_dlexit();
 		return MCRYPT_UNKNOWN_ERROR;
 	}
@@ -254,7 +258,7 @@ WIN32DLL_DEFINE
     int mcrypt_mode_module_ok(const char *file, const char *directory)
 {
 	word32 ret;
-	lt_dlhandle *_handle;
+	lt_dlhandle _handle;
 	int (*_version) (void);
 
 	if (file == NULL && directory == NULL) {
@@ -290,3 +294,76 @@ WIN32DLL_DEFINE
 	return ret;
 
 }
+
+/* Taken from libgcrypt */
+
+static const char*
+parse_version_number( const char *s, int *number )
+{
+    int val = 0;
+
+    if( *s == '0' && isdigit(s[1]) )
+	return NULL; /* leading zeros are not allowed */
+    for ( ; isdigit(*s); s++ ) {
+	val *= 10;
+	val += *s - '0';
+    }
+    *number = val;
+    return val < 0? NULL : s;
+}
+
+
+static const char *
+parse_version_string( const char *s, int *major, int *minor, int *micro )
+{
+    s = parse_version_number( s, major );
+    if( !s || *s != '.' )
+	return NULL;
+    s++;
+    s = parse_version_number( s, minor );
+    if( !s || *s != '.' )
+	return NULL;
+    s++;
+    s = parse_version_number( s, micro );
+    if( !s )
+	return NULL;
+    return s; /* patchlevel */
+}
+
+/****************
+ * Check that the the version of the library is at minimum the requested one
+ * and return the version string; return NULL if the condition is not
+ * satisfied.  If a NULL is passed to this function, no check is done,
+ * but the version string is simply returned.
+ */
+const char *
+mcrypt_check_version( const char *req_version )
+{
+    const char *ver = VERSION;
+    int my_major, my_minor, my_micro;
+    int rq_major, rq_minor, rq_micro;
+    const char *my_plvl, *rq_plvl;
+
+    if ( !req_version )
+	return ver;
+
+    my_plvl = parse_version_string( ver, &my_major, &my_minor, &my_micro );
+    if ( !my_plvl )
+	return NULL;  /* very strange our own version is bogus */
+    rq_plvl = parse_version_string( req_version, &rq_major, &rq_minor,
+								&rq_micro );
+    if ( !rq_plvl )
+	return NULL;  /* req version string is invalid */
+
+    if ( my_major > rq_major
+	|| (my_major == rq_major && my_minor > rq_minor)
+	|| (my_major == rq_major && my_minor == rq_minor
+				 && my_micro > rq_micro)
+	|| (my_major == rq_major && my_minor == rq_minor
+				 && my_micro == rq_micro
+				 && strcmp( my_plvl, rq_plvl ) >= 0) ) {
+	return ver;
+    }
+    return NULL;
+}
+
