@@ -1,5 +1,5 @@
 /*
- * $Id: cast-128.c,v 1.5 2001/01/23 11:51:19 nmav Exp $
+ * $Id: cast-128.c,v 1.6 2001/05/16 17:54:25 nmav Exp $
  *
  *	CAST-128 in C
  *	Written by Steve Reid <sreid@sea-to-sky.net>
@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: cast-128.c,v 1.5 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: cast-128.c,v 1.6 2001/05/16 17:54:25 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -64,8 +64,7 @@
 
 /***** Encryption Function *****/
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(CAST_KEY *key, u8 * block)
+WIN32DLL_DEFINE void _mcrypt_encrypt(CAST_KEY * key, u8 * block)
 {
 	u32 t, l, r;
 
@@ -110,8 +109,7 @@ void _mcrypt_encrypt(CAST_KEY *key, u8 * block)
 
 /***** Decryption Function *****/
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(CAST_KEY *key, u8 * block)
+WIN32DLL_DEFINE void _mcrypt_decrypt(CAST_KEY * key, u8 * block)
 {
 	u32 t, l, r;
 
@@ -157,8 +155,7 @@ void _mcrypt_decrypt(CAST_KEY *key, u8 * block)
 /***** Key Schedual *****/
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(CAST_KEY *key, u8 * rawkey,
-			 unsigned keybytes)
+    int _mcrypt_set_key(CAST_KEY * key, u8 * rawkey, unsigned keybytes)
 {
 	u32 t[4], z[4], x[4];
 	unsigned i;
@@ -298,77 +295,100 @@ int _mcrypt_set_key(CAST_KEY *key, u8 * rawkey,
 	for (i = 0; i < 4; i++) {
 		t[i] = x[i] = z[i] = 0;
 	}
-return 0;
+	return 0;
 }
 
 /* Made in Canada */
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(CAST_KEY);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 8; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 16; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	int* size=malloc(sizeof(int)*1);
-	size[0]=16;
-        *len= 1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(CAST_KEY);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 8;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 16;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(sizeof(int) * 1);
+	size[0] = 16;
+	*len = 1;
+	return size;
 }
 
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "CAST-128"); return x;}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "CAST-128");
+	return x;
+}
 
 #define CIPHER "434e25460c8c9525"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
-
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
