@@ -16,7 +16,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: cast-256.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: cast-256.c,v 1.7 2001/05/16 17:54:25 nmav Exp $ */
 
 /* modified for mcrypt */
 
@@ -357,8 +357,8 @@ word32 cast256_sbox[4][256] = { {
 
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(cast256_key * key, const word32 * in_key,
-		     const int key_len)
+    int _mcrypt_set_key(cast256_key * key, const word32 * in_key,
+			const int key_len)
 {
 	word32 i, j, t, u, cm, cr, lk[8], tm[8], tr[8];
 
@@ -406,13 +406,12 @@ int _mcrypt_set_key(cast256_key * key, const word32 * in_key,
 		key->l_key[i + 7] = lk[1];
 	}
 
-return 0;
+	return 0;
 }
 
 /* encrypt a block of text  */
 /* 16 bytes */
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(cast256_key * key, word32 * blk)
+WIN32DLL_DEFINE void _mcrypt_encrypt(cast256_key * key, word32 * blk)
 {
 	word32 t, u;
 
@@ -446,8 +445,7 @@ void _mcrypt_encrypt(cast256_key * key, word32 * blk)
 
 /* decrypt a block of text  */
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(cast256_key * key, word32 * blk)
+WIN32DLL_DEFINE void _mcrypt_decrypt(cast256_key * key, word32 * blk)
 {
 	word32 t, u;
 
@@ -479,42 +477,37 @@ void _mcrypt_decrypt(cast256_key * key, word32 * blk)
 
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size()
+WIN32DLL_DEFINE int _mcrypt_get_size()
 {
 	return sizeof(cast256_key);
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size()
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
 {
 	return 16;
 }
 
-WIN32DLL_DEFINE
-int _is_block_algorithm()
+WIN32DLL_DEFINE int _is_block_algorithm()
 {
 	return 1;
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size()
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
 {
 	return 32;
 }
 
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-        int *size=malloc(3*sizeof(int));
-        size[0]=16;
-        size[1]=24;
-        size[2]=32;
-        *len= 3;
-        return size;
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
+	return size;
 }
 
-WIN32DLL_DEFINE
-char *_mcrypt_get_algorithms_name()
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 {
 	char *x;
 	x = malloc(10);
@@ -524,31 +517,37 @@ char *_mcrypt_get_algorithms_name()
 
 #define CIPHER "5db4dd765f1d3835615a14afcb5dc2f5"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test()
+WIN32DLL_DEFINE int _mcrypt_self_test()
 {
 	char *keyword;
-	unsigned char *plaintext;
-	unsigned char *ciphertext;
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
 	int blocksize = _mcrypt_get_block_size(), j;
 	void *key;
 	unsigned char cipher_tmp[200];
 
 	keyword = calloc(1, _mcrypt_get_key_size());
+	if (keyword == NULL)
+		return -1;
+
 	for (j = 0; j < _mcrypt_get_key_size(); j++) {
 		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-	plaintext = malloc(blocksize);
+
 	for (j = 0; j < blocksize; j++) {
 		plaintext[j] = j % 256;
 	}
 	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
 	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
 	_mcrypt_encrypt(key, (void *) ciphertext);
 
+	free(keyword);
+
 	for (j = 0; j < blocksize; j++) {
 		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
 			ciphertext[j]);
@@ -558,19 +557,22 @@ int _mcrypt_self_test()
 		printf("failed compatibility\n");
 		printf("Expected: %s\nGot: %s\n", CIPHER,
 		       (char *) cipher_tmp);
+		free(key);
 		return -1;
 	}
 	_mcrypt_decrypt(key, (void *) ciphertext);
 
+	free(key);
+
 	if (strcmp(ciphertext, plaintext) != 0) {
 		printf("failed internally\n");
 		return -1;
 	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version()
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
 	return 19991129;
 }
