@@ -6,14 +6,14 @@
  *      but considerably trivialized.
  *
  *      A public-domain replacement for the UNIX "crypt" command.
- *      Changed to fit in mcrypt by nmav@i-net.paiko.gr
+ *      Changed to fit in mcrypt by nmav@hellug.gr
  */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: enigma.c,v 1.5 2001/04/25 09:49:11 nmav Exp $ */
+/* $Id: enigma.c,v 1.7 2001/05/16 18:00:09 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -40,7 +40,8 @@
  */
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2)
+    int _mcrypt_set_key(CRYPT_KEY * ckey, char *password, int plen,
+			void *u1, int u2)
 {
 	int ic, i, k, temp;
 	unsigned random;
@@ -50,10 +51,11 @@ int _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2)
 	Bzero(ckey, sizeof(CRYPT_KEY));
 	ckey->n1 = ckey->n2 = ckey->nr1 = ckey->nr2 = 0;
 
-	if (plen > 13) plen = 13;
+	if (plen > 13)
+		plen = 13;
+
+	memmove(ckey->cbuf, password, plen);
 
-	memmove( ckey->cbuf, password, plen);
-	
 	seed = 123;
 	for (i = 0; i < 13; i++)
 		seed = seed * ckey->cbuf[i] + i;
@@ -88,7 +90,7 @@ int _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2)
 }
 
 
-int shuffle(CRYPT_KEY* ckey)
+int shuffle(CRYPT_KEY * ckey)
 {
 	int i, ic, k, temp;
 	unsigned random;
@@ -107,10 +109,10 @@ int shuffle(CRYPT_KEY* ckey)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_encrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
+    void _mcrypt_encrypt(CRYPT_KEY * ckey, void *gtext, int textlen)
 {				/* 0 or 1 */
 	int i, j;
-	int secureflg=0;
+	int secureflg = 0;
 	char *text = gtext;
 
 	for (j = 0; j < textlen; j++) {
@@ -122,7 +124,11 @@ void _mcrypt_encrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
 		} else {
 			ckey->nr1 = ckey->n1;
 		}
-		i = ckey->t2[(ckey->t3[(ckey->t1[(i + ckey->nr1) & MASK] + ckey->nr2) & MASK] - ckey->nr2) & MASK] - ckey->nr1;
+		i = ckey->
+		    t2[(ckey->
+			t3[(ckey->t1[(i + ckey->nr1) & MASK] +
+			    ckey->nr2) & MASK] - ckey->nr2) & MASK] -
+		    ckey->nr1;
 		text[j] = i;
 		ckey->n1++;
 		if (ckey->n1 == ROTORSZ) {
@@ -142,10 +148,10 @@ void _mcrypt_encrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
 }
 
 WIN32DLL_DEFINE
-void _mcrypt_decrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
+    void _mcrypt_decrypt(CRYPT_KEY * ckey, void *gtext, int textlen)
 {				/* 0 or 1 */
 	int i, j;
-	int secureflg=0;
+	int secureflg = 0;
 	char *text = gtext;
 
 
@@ -158,7 +164,11 @@ void _mcrypt_decrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
 		} else {
 			ckey->nr1 = ckey->n1;
 		}
-		i = ckey->t2[(ckey->t3[(ckey->t1[(i + ckey->nr1) & MASK] + ckey->nr2) & MASK] - ckey->nr2) & MASK] - ckey->nr1;
+		i = ckey->
+		    t2[(ckey->
+			t3[(ckey->t1[(i + ckey->nr1) & MASK] +
+			    ckey->nr2) & MASK] - ckey->nr2) & MASK] -
+		    ckey->nr1;
 		text[j] = i;
 		ckey->n1++;
 		if (ckey->n1 == ROTORSZ) {
@@ -178,74 +188,101 @@ void _mcrypt_decrypt(CRYPT_KEY *ckey, void *gtext, int textlen)
 }
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(CRYPT_KEY);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_algo_iv_size() { return 0; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 0; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 13; }
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	*len=0;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(CRYPT_KEY);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_algo_iv_size()
+{
+	return 0;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 0;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 13;
+}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	*len = 0;
 	return NULL;
 }
 
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(6); strcpy(x, "crypt"); return x;}
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(6);
+	strcpy(x, "crypt");
+	return x;
+}
 
 #define CIPHER "f3edda7da20f8975884600f014d32c7a08e59d7b"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=20, j;
-        void *key;
-        unsigned char cipher_tmp[200];
+	unsigned char plaintext[20];
+	unsigned char ciphertext[20];
+	int blocksize = 20, j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
+	keyword = calloc(1, _mcrypt_get_key_size());
+	if (keyword == NULL)
+		return -1;
 
-	keyword = calloc(1, _mcrypt_get_key_size()); 
 	strcpy(keyword, "enadyotr");
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
-	}
-	key=malloc(_mcrypt_get_size());
-	memmove(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL, 0);
-	if (key==NULL) {
-		printf ("Internal error (NULL key)\n"); 
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
+	}
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
 		return -1;
 	}
-	_mcrypt_encrypt( key, (void*)ciphertext, blocksize);
+	memmove(ciphertext, plaintext, blocksize);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size(),
+			NULL, 0);
+	_mcrypt_encrypt(key, (void *) ciphertext, blocksize);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL, 0);
-	_mcrypt_decrypt( key, (void*)ciphertext,  blocksize);
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(keyword);
+		free(key);
+		return -1;
 	}
+
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size(),
+			NULL, 0);
+	free(keyword);
+	
+	_mcrypt_decrypt(key, (void *) ciphertext, blocksize);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 20000316;
 }
