@@ -1,6 +1,6 @@
 /* panama_x.c */
 
-/* $Id: panama.c,v 1.9 2001/02/01 10:34:51 nmav Exp $ */
+/* $Id: panama.c,v 1.13 2001/05/21 09:34:40 nmav Exp $ */
 
 /* daemen.j@protonworld.com */
 /**************************************************************************+
@@ -323,7 +323,7 @@
 *
 +**************************************************************************/
 
-void pan_pull(word32 * restrict In,	/* input array                   */
+static void pan_pull(word32 * restrict In,	/* input array                   */
 	      word32 * restrict Out,	/* output array                  */
 	      word32 pan_blocks,	/* number of blocks to be Pulled */
 	      PAN_BUFFER * restrict buffer,	/* LFSR buffer                   */
@@ -416,7 +416,7 @@ void pan_pull(word32 * restrict In,	/* input array                   */
 *
 +**************************************************************************/
 
-void pan_push(word32 * restrict In,	/* input array                   */
+static void pan_push(word32 * restrict In,	/* input array                   */
 	      word32 pan_blocks,	/* number of blocks to be Pushed */
 	      PAN_BUFFER * restrict buffer,	/* LFSR buffer                   */
 	      PAN_STATE * restrict state)
@@ -491,7 +491,7 @@ void pan_push(word32 * restrict In,	/* input array                   */
 *
 +**************************************************************************/
 
-void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state)
+static void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state)
 {
 	int i, j;
 
@@ -516,29 +516,31 @@ void pan_reset(PAN_BUFFER * buffer, PAN_STATE * state)
 +**************************************************************************/
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
-			 char *init_vec, int vecsize)
+    int _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
+			char *init_vec, int vecsize)
 {
-	char* key;
+	char *key;
 	int keyblocks = (8 * keysize) / (PAN_STAGE_SIZE * WORDLENGTH);
 	int vecblocks = (8 * vecsize) / (PAN_STAGE_SIZE * WORDLENGTH);
 #ifdef WORDS_BIGENDIAN
 	int i;
-	
-	key=mxcalloc(1, 32);
-	if (key==NULL) return -1;
-	
-	memmove( key, in_key, keysize);
+
+	key = calloc(1, 32);
+	if (key == NULL)
+		return -1;
+
+	memmove(key, in_key, keysize);
 #else
-	key=in_key;
+	key = in_key;
 #endif
 
 /* initialize the Panama state machine for a fresh crypting operation */
 	pan_reset(&pan_key->buffer, &pan_key->state);
 	pan_push((void *) key, keyblocks, &pan_key->buffer,
 		 &pan_key->state);
-	if (init_vec!=NULL) pan_push((void *) init_vec, vecblocks, &pan_key->buffer,
-		 &pan_key->state);
+	if (init_vec != NULL)
+		pan_push((void *) init_vec, vecblocks, &pan_key->buffer,
+			 &pan_key->state);
 
 	pan_pull(NULL, NULL, 32, &pan_key->buffer, &pan_key->state);
 
@@ -547,20 +549,20 @@ int _mcrypt_set_key(PANAMA_KEY * pan_key, char *in_key, int keysize,
 	pan_key->keymat_pointer = 0;
 #ifdef WORDS_BIGENDIAN
 	for (i = 0; i < 8; i++) {
-		
-		    ((word32 *) pan_key->keymat)[i] =
+
+		((word32 *) pan_key->keymat)[i] =
 		    byteswap32(((word32 *) pan_key->keymat)[i]);
 	}
-	mxfree(key,32);
+	memset( key, 0, 32);
+	free(key);
 #endif
 
-return 0;
+	return 0;
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
-		    byte * buf,	/* input array                         */
-		    int length)
+WIN32DLL_DEFINE void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
+				     byte * buf,	/* input array                         */
+				     int length)
 {				/* length to be encrypted, in bits     */
 	int i;
 #ifdef WORDS_BIGENDIAN
@@ -576,9 +578,9 @@ void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
 			pan_key->keymat_pointer = 0;
 #ifdef WORDS_BIGENDIAN
 			for (j = 0; j < 8; j++) {
-				    ((word32 *) pan_key->keymat)[j] =
+				((word32 *) pan_key->keymat)[j] =
 				    byteswap32(((word32 *) pan_key->keymat)
-					     [j]);
+					       [j]);
 			}
 #endif
 		}
@@ -587,90 +589,117 @@ void _mcrypt_encrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
 	}
 }
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
-		    byte * buf,	/* input array                         */
-		    int length)
+WIN32DLL_DEFINE void _mcrypt_decrypt(PANAMA_KEY * pan_key,	/* the key from pan_init */
+				     byte * buf,	/* input array                         */
+				     int length)
 {				/* length to be encrypted, in bits     */
-   _mcrypt_encrypt( pan_key, buf, length);
+	_mcrypt_encrypt(pan_key, buf, length);
 }
 
 /**************************************************************************/
 
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(PANAMA_KEY);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_algo_iv_size() { return 32; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 0; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	int *size=malloc(1*sizeof(int));
-	size[0]=32;
-	*len=1;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(PANAMA_KEY);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_algo_iv_size()
+{
+	return 32;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 0;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
 }
 
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(5); strcpy(x, "PANAMA"); return x;}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(1 * sizeof(int));
+	size[0] = 32;
+	*len = 1;
+	return size;
+}
+
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(5);
+	strcpy(x, "PANAMA");
+	return x;
+}
 
 #define CIPHER "d76e3c2243feadd2c99edfcb95c64c852ba6c59f"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=20, j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[20];
+	unsigned char ciphertext[20];
+	int blocksize = 20, j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = ((j * 2 + 10) % 256);
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = malloc(blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL) {
+		free(keyword);
+		return -1;
+	}
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL, 0);
-	_mcrypt_encrypt( key, (void*)ciphertext, blocksize);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size(),
+			NULL, 0);
+	_mcrypt_encrypt(key, (void *) ciphertext, blocksize);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
+	}
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(keyword);
+		free(key);
+		return -1;
 	}
-/*        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=((j*2+10)%256);
-	}
- */
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size(), NULL,0);
-	_mcrypt_decrypt( key, (void*)ciphertext,  blocksize);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size(),
+			NULL, 0);
+	free(keyword);
+
+	_mcrypt_decrypt(key, (void *) ciphertext, blocksize);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
 	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version(void) {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version(void)
+{
 	return 20010201;
 }
