@@ -20,7 +20,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: twofish.c,v 1.6 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: twofish.c,v 1.7 2001/05/16 17:54:25 nmav Exp $ */
 
 /* Timing data for Twofish (twofish.c)
 
@@ -86,22 +86,26 @@ byte ror4[16] = { 0, 8, 1, 9, 2, 10, 3, 11, 4, 12, 5, 13, 6, 14, 7, 15 };
 byte ashx[16] = { 0, 9, 2, 11, 4, 13, 6, 15, 8, 1, 10, 3, 12, 5, 14, 7 };
 
 byte qt0[2][16] = {
-	{8, 1, 7, 13, 6, 15, 3, 2, 0, 11, 5, 9, 14, 12, 10, 4},
+	{8, 1, 7, 13, 6, 15, 3, 2, 0, 11, 5, 9, 14, 12, 10, 4}
+	,
 	{2, 8, 11, 13, 15, 7, 6, 14, 3, 1, 9, 4, 0, 10, 12, 5}
 };
 
 byte qt1[2][16] = {
-	{14, 12, 11, 8, 1, 2, 3, 5, 15, 4, 10, 6, 7, 0, 9, 13},
+	{14, 12, 11, 8, 1, 2, 3, 5, 15, 4, 10, 6, 7, 0, 9, 13}
+	,
 	{1, 14, 2, 11, 4, 12, 3, 7, 6, 13, 10, 5, 15, 9, 0, 8}
 };
 
 byte qt2[2][16] = {
-	{11, 10, 5, 14, 6, 13, 9, 0, 12, 8, 15, 3, 2, 4, 7, 1},
+	{11, 10, 5, 14, 6, 13, 9, 0, 12, 8, 15, 3, 2, 4, 7, 1}
+	,
 	{4, 12, 7, 5, 1, 6, 9, 10, 0, 14, 13, 8, 2, 11, 3, 15}
 };
 
 byte qt3[2][16] = {
-	{13, 7, 15, 4, 1, 2, 6, 14, 9, 11, 3, 0, 8, 5, 12, 10},
+	{13, 7, 15, 4, 1, 2, 6, 14, 9, 11, 3, 0, 8, 5, 12, 10}
+	,
 	{11, 9, 5, 1, 12, 3, 13, 14, 6, 4, 7, 15, 2, 0, 8, 10}
 };
 
@@ -421,8 +425,8 @@ word32 mds_rem(word32 p0, word32 p1)
 
 /* initialise the key schedule from the user supplied key   */
 WIN32DLL_DEFINE
-int _mcrypt_set_key(TWI * pkey, const word32 in_key[],
-			     const word32 key_len)
+    int _mcrypt_set_key(TWI * pkey, const word32 in_key[],
+			const word32 key_len)
 {
 	word32 i, a, b, me_key[4], mo_key[4];
 
@@ -471,7 +475,7 @@ int _mcrypt_set_key(TWI * pkey, const word32 in_key[],
 #ifdef MK_TABLE
 	gen_mk_tab(pkey, pkey->s_key);
 #endif
-return 0;
+	return 0;
 }
 
 /* encrypt a block of text  */
@@ -484,8 +488,7 @@ return 0;
     blk[0] = rotr32(blk[0] ^ (t0 + t1 + pkey->l_key[4 * (i) + 10]), 1);     \
     blk[1] = rotl32(blk[1], 1) ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) + 11])
 
-WIN32DLL_DEFINE
-void _mcrypt_encrypt(TWI * pkey, word32 * in_blk)
+WIN32DLL_DEFINE void _mcrypt_encrypt(TWI * pkey, word32 * in_blk)
 {
 	word32 t0, t1, blk[4];
 #ifdef WORDS_BIGENDIAN
@@ -532,8 +535,7 @@ void _mcrypt_encrypt(TWI * pkey, word32 * in_blk)
         blk[0] = rotl32(blk[0], 1) ^ (t0 + t1 + pkey->l_key[4 * (i) +  8]);     \
         blk[1] = rotr32(blk[1] ^ (t0 + 2 * t1 + pkey->l_key[4 * (i) +  9]), 1)
 
-WIN32DLL_DEFINE
-void _mcrypt_decrypt(TWI * pkey, word32 * in_blk)
+WIN32DLL_DEFINE void _mcrypt_decrypt(TWI * pkey, word32 * in_blk)
 {
 	word32 t0, t1, blk[4];
 
@@ -572,74 +574,98 @@ void _mcrypt_decrypt(TWI * pkey, word32 * in_blk)
 
 }
 
-WIN32DLL_DEFINE
-int _mcrypt_get_size () {return sizeof(TWI);}
-WIN32DLL_DEFINE
-int _mcrypt_get_block_size() { return 16; }
-WIN32DLL_DEFINE
-int _is_block_algorithm() { return 1; }
-WIN32DLL_DEFINE
-int _mcrypt_get_key_size() { return 32; }
-
-WIN32DLL_DEFINE
-int* _mcrypt_get_supported_key_sizes(int *len) {
-	int *size=malloc(3*sizeof(int));
-        size[0]=16;
-        size[1]=24;
-        size[2]=32;
-	*len=3;
-        return size;
+WIN32DLL_DEFINE int _mcrypt_get_size()
+{
+	return sizeof(TWI);
+}
+WIN32DLL_DEFINE int _mcrypt_get_block_size()
+{
+	return 16;
+}
+WIN32DLL_DEFINE int _is_block_algorithm()
+{
+	return 1;
+}
+WIN32DLL_DEFINE int _mcrypt_get_key_size()
+{
+	return 32;
 }
 
-WIN32DLL_DEFINE
-char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Twofish"); return x;}
+WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+{
+	int *size = malloc(3 * sizeof(int));
+	size[0] = 16;
+	size[1] = 24;
+	size[2] = 32;
+	*len = 3;
+	return size;
+}
+
+WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+{
+	char *x;
+	x = malloc(10);
+	strcpy(x, "Twofish");
+	return x;
+}
 
 #define CIPHER "cc1c778374bccd6e73bfc642384cef7d"
 
-WIN32DLL_DEFINE
-int _mcrypt_self_test() {
+WIN32DLL_DEFINE int _mcrypt_self_test()
+{
 	char *keyword;
-	unsigned char *plaintext;
-        unsigned char *ciphertext;
-        int blocksize=_mcrypt_get_block_size(), j;
-        void *key;
-        unsigned char cipher_tmp[200];
-                         
+	unsigned char plaintext[16];
+	unsigned char ciphertext[16];
+	int blocksize = _mcrypt_get_block_size(), j;
+	void *key;
+	unsigned char cipher_tmp[200];
+
 	keyword = calloc(1, _mcrypt_get_key_size());
-        for (j=0; j< _mcrypt_get_key_size(); j++) {
-	        keyword[j]=(j*2+10)%256;
+	if (keyword == NULL)
+		return -1;
+
+	for (j = 0; j < _mcrypt_get_key_size(); j++) {
+		keyword[j] = (j * 2 + 10) % 256;
 	}
-	ciphertext = malloc(blocksize);
-        plaintext = calloc(1, blocksize);
-        for (j=0; j< blocksize; j++) {
-	        plaintext[j]=j%256;
+
+	for (j = 0; j < blocksize; j++) {
+		plaintext[j] = j % 256;
 	}
-	key=malloc(_mcrypt_get_size());
+	key = malloc(_mcrypt_get_size());
+	if (key == NULL)
+		return -1;
+
 	memcpy(ciphertext, plaintext, blocksize);
 
-	_mcrypt_set_key( key, (void*)keyword, _mcrypt_get_key_size());
-	_mcrypt_encrypt( key, (void*)ciphertext);
+	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size());
+	free(keyword);
 
-        for (j = 0; j < blocksize; j++) {
-               sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
-               ciphertext[j]);
-        }
+	_mcrypt_encrypt(key, (void *) ciphertext);
 
-	if (strcmp( (char*)cipher_tmp, CIPHER) != 0) {
-	        printf("failed compatibility\n");
-	        printf("Expected: %s\nGot: %s\n", CIPHER, (char*)cipher_tmp);
-	        return -1;
+	for (j = 0; j < blocksize; j++) {
+		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
+			ciphertext[j]);
 	}
-	_mcrypt_decrypt( key, (void*)ciphertext);
 
-	if (strcmp( ciphertext, plaintext) != 0) {
-	        printf("failed internally\n");
-	        return -1;
+	if (strcmp((char *) cipher_tmp, CIPHER) != 0) {
+		printf("failed compatibility\n");
+		printf("Expected: %s\nGot: %s\n", CIPHER,
+		       (char *) cipher_tmp);
+		free(key);
+		return -1;
 	}
+	_mcrypt_decrypt(key, (void *) ciphertext);
+	free(key);
+
+	if (strcmp(ciphertext, plaintext) != 0) {
+		printf("failed internally\n");
+		return -1;
+	}
+
 	return 0;
 }
 
-WIN32DLL_DEFINE
-word32 _mcrypt_algorithm_version() {
+WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
+{
 	return 19991129;
 }
