@@ -120,7 +120,7 @@ WIN32DLL_DEFINE
 	if (ivlen > 32)
 		wake_key->ivsize = 32;
 	else
-		wake_key->ivsize = ivlen/4*4;
+		wake_key->ivsize = ivlen / 4 * 4;
 
 	if (IV == NULL)
 		wake_key->ivsize = 0;
@@ -312,8 +312,8 @@ WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 WIN32DLL_DEFINE int _mcrypt_self_test()
 {
 	unsigned char *keyword;
-	unsigned char *plaintext;
-	unsigned char *ciphertext;
+	unsigned char plaintext[43];
+	unsigned char ciphertext[43];
 	int blocksize = 43, j;
 	void *key, *key2;
 	unsigned char cipher_tmp[200];
@@ -323,8 +323,6 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 		keyword[j] = (j * 5 + 10) & 0xff;
 	}
 
-	ciphertext = malloc(blocksize);
-	plaintext = malloc(blocksize);
 	for (j = 0; j < blocksize; j++) {
 		plaintext[j] = (j + 5) % 0xff;
 	}
@@ -336,6 +334,7 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 	_mcrypt_set_key(key, (void *) keyword, _mcrypt_get_key_size(),
 			NULL, 0);
 	_mcrypt_encrypt(key, (void *) ciphertext, blocksize);
+	free(key);
 
 	for (j = 0; j < blocksize; j++) {
 		sprintf(&((char *) cipher_tmp)[2 * j], "%.2x",
@@ -346,16 +345,22 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 		printf("failed compatibility\n");
 		printf("Expected: %s\nGot: %s\n", CIPHER,
 		       (char *) cipher_tmp);
+		free(key);
+		free(key2);
 		return -1;
 	}
 	_mcrypt_set_key(key2, (void *) keyword, _mcrypt_get_key_size(),
 			NULL, 0);
+	free(keyword);
+
 	_mcrypt_decrypt(key2, (void *) ciphertext, blocksize);
+	free(key2);
 
 	if (memcmp(ciphertext, plaintext, blocksize) != 0) {
 		printf("failed internally\n");
 		return -1;
 	}
+
 	return 0;
 }
 
